#
# spec file for package autoconf (Version 2.67)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           autoconf
BuildRequires:  help2man xz
License:        GPLv3+
Group:          Development/Tools/Building
Url:            http://www.gnu.org/software/autoconf
AutoReqProv:    on
Requires:       m4 >= 1.4.6
PreReq:         %{install_info_prereq}
Version:        2.67
Release:        2.2
Summary:        A GNU Tool for Automatically Configuring Source Code
Source:         autoconf-%{version}.tar.xz
Patch0:         autoreconf-ltdl.diff
# PATCH-FIX-UPSTREAM -2.67-fix_dnl.patch andrea@opensuse.org
# this patch fix savannah bug #107447 regression in AC_MSG_ERROR expansion
Patch1:         autoconf-2.67-fix_dnl.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
GNU Autoconf is a tool for configuring source code and makefiles. Using
autoconf, programmers can create portable and configurable packages,
because the person building the package is allowed to specify various
configuration options.

You should install autoconf if you are developing software and would
like to create shell scripts to configure your source code packages.

Note that the autoconf package is not required for the end user who may
be configuring software with an autoconf-generated script; autoconf is
only required for the generation of the scripts, not their use.

%prep
%setup -q -n autoconf-%{version}
%patch0
%patch1 -p1

%build
%{suse_update_config -f config}
./configure --prefix=%{_prefix} --infodir=%{_infodir} --mandir=%{_mandir}
make %{?_smp_mflags}

%if "%{name}" == "autoconf-testsuite"

%check
trap 'test $? -ne 0 && cat tests/testsuite.log' EXIT
make check

%install
%else

%install
make install DESTDIR=$RPM_BUILD_ROOT
rm -f $RPM_BUILD_ROOT%{_prefix}/share/emacs/site-lisp/*.el*
%endif

%post
%install_info --info-dir=%{_infodir} %{_infodir}/autoconf.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/autoconf.info.gz

%clean
rm -rf $RPM_BUILD_ROOT

%if "%{name}" == "autoconf"

%files
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS README TODO
%{_prefix}/bin/*
%{_prefix}/share/autoconf
%doc %{_infodir}/*.gz
%doc %{_mandir}/man1/*.gz
%endif

%changelog
* Sun Sep 19 2010 andrea@opensuse.org
- added patch autoconf-2.67-fix_dnl.patch to fix regression in
  AC_MSG_ERROR expansion (undefined macro: AS_MESSAGE_LOG_FDdnl)
* Wed Aug 18 2010 pth@suse.de
- Update to 2.67:
  * New macro AC_FC_LINE_LENGTH to accept long Fortran source code
    lines.
  * AC_PREPROC_IFELSE now keeps the preprocessed output in the
    conftest.i file for inspection by the commands in the
    ACTION-IF-TRUE argument.
  * autoreconf passes warning flags to new enough versions of
    aclocal.
  * Running an Autotest testsuite in parallel mode no longer triggers
    a race condition that could cause the testsuite run to end early,
    fixing a sporadic failure in autoconf's own testsuite.  Bug
    present since introduction of parallel tests in 2.63b.
  Major changes in Autoconf 2.66 (2010-07-02) [stable]
  * AC_FUNC_MMAP works in C++ mode again.  Regression introduced in
    2.65.
  * Use of m4_divert without a named diversion now issues a syntax
    warning, since it is seldom right to change diversions behind
    autoconf's back.
  * The macros AC_TYPE_INT8_T, AC_TYPE_INT16_T, AC_TYPE_INT32_T, and
    AC_TYPE_INT64_T work again.  Regression introduced in 2.65.
  * AC_PROG_INSTALL correctly uses `shtool' again.  Regression
    introduced in 2.64.
  * Autoconf should work on EBCDIC hosts.
  * AC_CHECK_DECL and AC_CHECK_DECLS accept optional function
    argument types for overloaded C++ functions.
  * AS_SET_CATFILE accepts nonliterals in its variable name argument
    now.
  * Autotest testsuites accept an option --recheck to rerun tests
    that failed or passed unexpectedly during the last non-debug
    testsuite run.
  * AC_ARG_ENABLE and AC_ARG_WITH now also accept `+' signs in
    `--enable-*' and `--with-*' arguments, converting them to
    underscores for the variable names.
  * In configure scripts, loading CONFIG_SITE no longer searches
    PATH, and problems in loading the configuration site files are
    diagnosed.
  * Autotest testsuites may optionally provide colored test results.
  * The previously undocumented Autotest macros AT_ARG_OPTION and
    AT_ARG_OPTION_ARG have seen bug fixes and are documented now.
    AT_ARG_OPTION has been changed in that the negative of a long
    option --OPTION is now --no-OPTION rather than --noOPTION.
  * The macro AS_LITERAL_IF is slightly more conservative; text
    containing shell quotes are no longer treated as literals.
    Furthermore, a new macro, AS_LITERAL_WORD_IF, adds an additional
    level of checking that no whitespace occurs in literals.
  * The macros AS_TR_SH and AS_TR_CPP no longer expand their results.
  * The following macros are now documented:
    AS_BOX
  * New macro AC_FC_FIXEDFORM to accept fixed-form Fortran.
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Mon May 31 2010 coolo@novell.com
- add empty install section
* Fri May 28 2010 coolo@novell.com
- split out test suite that takes 95%% of the build time
* Wed Feb 17 2010 poletti.marco@gmail.com
- Update to 2.65
  * * Autoconf is now licensed under the GPLv3+.
  * * The manual is now shipped under the terms of the GNU FDL 1.3.
  * * config.status now provides a --config option to produce the configuration.
  * * Autoconf now requires GNU M4 1.4.6 or later. GNU M4 1.4.13 or
    later is recommended.
  * * Autotest testsuites accept an option --jobs[=N] for parallel testing.
    This feature is still in testing, and may not work on every
    platform, help in improving it would be appreciated.
* Sun Dec  6 2009 jengelh@medozas.de
- enable parallel building
* Fri Jul 17 2009 dominique-obs@leuenberger.net
- Add autoconf-xfail-test27.patch
  + It skips test 27 ([autom4te preselections]) as it's an
    incompatibility between autoconf 2.63 and automake 1.11
    ! This patch needs to be removed with autoconf 2.64 again !
* Wed Sep 10 2008 schwab@suse.de
- Update to autoconf 2.63.
  * * AC_C_BIGENDIAN does not mistakenly report "universal" for some
    bigendian hosts, a regression introduced with universal binary
    support in 2.62.
  * * AC_PATH_X now includes /lib64 and /usr/lib64 in its list of default
    library directories.
  * * AC_USE_SYSTEM_EXTENSIONS no longer conflicts with an external
    AC_DEFINE([__EXTENSIONS__]).  This fixes a regression introduced in
    2.62 when using macros such as AC_AIX that were made obsolete in
    favor of the more portable AC_USE_SYSTEM_EXTENSIONS.
  * * AC_CHECK_TARGET_TOOLS is usable in the non-cross-compile case.
  * * Newly obsolete macros
    The following macro has been marked obsolete, since current porting
    targets can safely assume C89 semantics that signal handlers return
    void.  We have no current plans to remove the macro.
    AC_TYPE_SIGNAL
  * * The macros m4_map and m4_map_sep now ignore any list elements
    consisting of just empty quotes, and m4_map_sep now expands its
    separator.  This fixes a regression in 2.62 when these macros were
    first documented, for the sake of clients expecting the semantics
    that these macros had prior to that time.  The new macros m4_mapall
    and m4_mapall_sep, along with extra quoting of the separator, can
    be used to get the semantics that m4_map_sep had in 2.62.
  * * Clients of m4_expand, such as AS_HELP_STRING and AT_SETUP, can now
    handle properly quoted but otherwise unbalanced parentheses (for
    some macros, this fixes a regression in 2.62).
  * * Two new quadrigraphs have been introduced: @{:@ for (, and @:}@ for ),
    allowing the output of unbalanced parentheses in more contexts.
  * * The following m4sugar macros are new:
    m4_joinall  m4_mapall  m4_mapall_sep  m4_reverse  m4_set_add
    m4_set_add_all  m4_set_contains  m4_set_contents  m4_set_delete
    m4_set_difference  m4_set_dump  m4_set_empty  m4_set_foreach
    m4_set_intersection  m4_set_list  m4_set_listc  m4_set_remove
    m4_set_size  m4_set_union
  * * The following m4sugar macros now accept multiple arguments, as is the
    case with underlying m4:
    m4_defn  m4_popdef  m4_undefine
  * * The following m4sugar macros now guarantee linear scaling; they
    previously had linear scaling with m4 1.6 but quadratic scaling
    when using m4 1.4.x.  All macros built on top of these also gain
    the scaling improvements.
    m4_bmatch  m4_bpatsubsts  m4_case  m4_cond  m4_do  m4_dquote_elt
    m4_foreach  m4_join  m4_list_cmp  m4_map  m4_map_sep  m4_max
    m4_min  m4_shiftn
  * * AT_KEYWORDS once again performs expansion on its argument, such that
    AT_KEYWORDS([m4_if([$1], [], [default])]) no longer complains about
    the possibly unexpanded m4_if [regression introduced in 2.62].
  * * Config header templates `#undef UNDEFINED /* comment */' do not lead to
    nested comments any more; regression introduced in 2.62.
* Thu Jul 17 2008 schwab@suse.de
- Revert AC_C_BIGENDIAN change for now.
- Fix config header substitution.
* Wed Apr  9 2008 schwab@suse.de
- Update to autoconf 2.62.
  <http://git.savannah.gnu.org/gitweb/?p=autoconf.git;a=blobdiff;f=NEWS;h=ef008867d725a89b743b20eeba97bec09e906fd6;hp=2a49e0feb1b4101bb5252fdd137992ec49f468fa>
* Mon Mar 10 2008 schwab@suse.de
- Fix spurious testsuite failure.
* Tue Feb 19 2008 schwab@suse.de
- Fix undefined behaviour in AC_FUNC_MKTIME test.
* Fri Jun  1 2007 schwab@suse.de
- Relax m4 requirement to work around autobuild bug.
* Mon Apr  2 2007 schwab@suse.de
- Fix spurious testsuite failure.
* Sun Mar 25 2007 schwab@suse.de
- Display testsuite log on failure.
* Wed Dec 13 2006 schwab@suse.de
- Handle old style libltdl macros.
* Mon Dec  4 2006 schwab@suse.de
- Update to autoconf 2.61.
  * * New macros AC_C_FLEXIBLE_ARRAY_MEMBER, AC_C_VARARRAYS.
  * * AC_ARG_ENABLE and AC_ARG_WITH now allow '.' in feature and package names.
* Wed Aug  2 2006 schwab@suse.de
- Split off autoconf-el.
* Thu Jul 20 2006 schwab@suse.de
- Fix testsuite.
* Tue Jun 27 2006 schwab@suse.de
- Update to autoconf 2.60, see
  <http://cvs.savannah.gnu.org/viewcvs/autoconf/autoconf/NEWS?r1=1.388&r2=1.322>.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jun 18 2004 schwab@suse.de
- Require exact version of m4.
* Thu Nov 13 2003 schwab@suse.de
- Update to autoconf 2.59, incorporates last change.
* Mon Nov 10 2003 schwab@suse.de
- Fix abs_srcdir.
* Tue Nov  4 2003 schwab@suse.de
- Update to autoconf 2.58.
* Thu Sep 18 2003 schwab@suse.de
- Downgrade flock failure to a warning [#26962].
* Mon Sep  8 2003 schwab@suse.de
- Add patch to serialize access to autom4te cache file [#26962].
* Mon May 12 2003 schwab@suse.de
- Add %%defattr.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Apr  7 2003 schwab@suse.de
- Only delete info entries when removing last version.
* Thu Feb  6 2003 schwab@suse.de
- Use %%install_info.
* Thu Dec  5 2002 schwab@suse.de
- Update to autoconf 2.57.
  * Bug fixes for problems with AIX linker, with freestanding C compilers,
    with GNU m4 limitations, and with obsolete copies of GNU documents.
* Fri Nov 15 2002 schwab@suse.de
- Update to autoconf 2.56.
* Tue Jun 11 2002 schwab@suse.de
- Fix missing info dir entries.
* Mon May 13 2002 schwab@suse.de
- Fix invalid node name in docs [#16078].
* Fri Apr 12 2002 schwab@suse.de
- Remove g77 from neededforbuild.
* Mon Apr  8 2002 schwab@suse.de
- Run automake last in autoreconf.
* Sun Apr  7 2002 schwab@suse.de
- Fix _AC_SRCPATHS.
* Thu Apr  4 2002 schwab@suse.de
- Fix _AS_PATH_WALK.
* Tue Apr  2 2002 schwab@suse.de
- Fix premature expansion in m4_bmatch.
* Sat Mar 30 2002 schwab@suse.de
- Handle libltdl in autoreconf.
- Run automake after aclocal in autoreconf.
* Fri Mar 15 2002 schwab@suse.de
- Handle gettext 0.11 in autoreconf.
* Sat Mar  9 2002 schwab@suse.de
- Update to autoconf 2.53.
* Sat Jul 21 2001 schwab@suse.de
- Always set {host,build,target}_alias.
* Thu Jul 19 2001 schwab@suse.de
- Update to autoconf 2.52.
* Mon Jun 11 2001 olh@suse.de
- recognize ppc64
* Tue May 22 2001 schwab@suse.de
- Update to autoconf 2.50.
- Add Buildroot.
* Fri Mar 23 2001 schwab@suse.de
- Add m4 as neededforbuild.
- Require m4 and gawk.
* Wed Mar 21 2001 schwab@suse.de
- Set F77 to g77 during `make check'.
* Wed Feb 21 2001 schwab@suse.de
- Fix AC_PROC_CXXCPP.
- Add %%suse_update_config.
- Don't mark acconfig.h as %%config.
- Run testsuite.
* Thu Jun  1 2000 kukuk@suse.de
- Add more docu, fill out group tag
* Mon May  1 2000 kukuk@suse.de
- Use infodir macro
* Fri Mar 24 2000 schwab@suse.de
- Fix conflicting declaration of exit.
* Tue Jan 18 2000 schwab@suse.de
- Undefine m4 macro `symbols' (new builtin in m4 1.4o).
* Mon Dec  6 1999 schwab@suse.de
- Discard output from `type -p'.
* Thu Dec  2 1999 schwab@suse.de
- Make sure tempfiles are always removed.
- Fix some quoting bugs in shell scripts.
* Thu Nov  4 1999 ro@suse.de
- fixed for alphaev6
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Aug 25 1999 kukuk@suse.de
- Specfile cleanup
* Fri Jan 15 1999 ro@suse.de
- update to 2.13
* Thu Jul 23 1998 werner@suse.de
- Make auto*.sh more secure and use mktemp if avaliable
* Wed Jan 22 1997 florian@suse.de
- update to version 2.12
